@@ -29,6 +29,7 @@ import (
 
 // Builder is used to build cobra commands.
 type Builder interface {
+	WithArgs(cobra.PositionalArgs, func(context.Context, io.Writer, []string) error) *cobra.Command
 	WithDescription(description string) Builder
 	WithLongDescription(long string) Builder
 	WithExample(comment, command string) Builder
@@ -89,11 +90,11 @@ func (b *builder) WithFlagAdder(adder func(*pflag.FlagSet)) Builder {
 
 func (b *builder) WithFlags(flags []*Flag) Builder {
 	for _, f := range flags {
-		fl := f.flag()
+		fl := f.flag(b.cmd.Use)
 		b.cmd.Flags().AddFlag(fl)
 	}
 	b.cmd.PreRun = func(cmd *cobra.Command, args []string) {
-		ParseFlags(cmd, flags)
+		ResetFlagDefaults(cmd, flags)
 	}
 
 	return b
@@ -132,6 +133,20 @@ func (b *builder) NoArgs(action func(context.Context, io.Writer) error) *cobra.C
 	return &b.cmd
 }
 
+func (b *builder) WithArgs(f cobra.PositionalArgs, action func(context.Context, io.Writer, []string) error) *cobra.Command {
+	b.cmd.Args = f
+	b.cmd.RunE = func(_ *cobra.Command, args []string) error {
+		err := handleWellKnownErrors(action(b.cmd.Context(), b.cmd.OutOrStdout(), args))
+		// clean up server at end of the execution since post run hooks are only executed if
+		// RunE is successful
+		if shutdownAPIServer != nil {
+			shutdownAPIServer()
+		}
+		return err
+	}
+	return &b.cmd
+}
+
 func handleWellKnownErrors(err error) error {
 	if err == nil {
 		return err
