@@ -38,7 +38,7 @@ func TestNewCmdDebug(t *testing.T) {
 
 		t.CheckDeepEqual(true, opts.Tail)
 		t.CheckDeepEqual(false, opts.Force)
-		t.CheckDeepEqual(false, opts.EnableRPC)
+		t.CheckDeepEqual(true, opts.EnableRPC)
 	})
 }
 
