@@ -40,6 +40,7 @@ type installOpts struct {
 	force        bool
 	helmVersion  semver.Version
 	postRenderer string
+	repo         string
 }
 
 // constructOverrideArgs creates the command line arguments for overrides
@@ -152,6 +153,11 @@ func (h *Deployer) installArgs(r latest.HelmRelease, builds []build.Artifact, va
 		args = append(args, "--namespace", o.namespace)
 	}
 
+	if o.repo != "" {
+		args = append(args, "--repo")
+		args = append(args, o.repo)
+	}
+
 	if r.CreateNamespace != nil && *r.CreateNamespace && !o.upgrade {
 		if o.helmVersion.LT(helm32Version) {
 			return nil, createNamespaceErr(h.bV.String())
