@@ -17,9 +17,11 @@ limitations under the License.
 package docker
 
 import (
+	"bytes"
 	"context"
 	"fmt"
 	"io"
+	"io/ioutil"
 	"os"
 	"path"
 	"path/filepath"
@@ -27,6 +29,7 @@ import (
 
 	v1 "github.com/google/go-containerregistry/pkg/v1"
 	"github.com/moby/buildkit/frontend/dockerfile/command"
+	"github.com/moby/buildkit/frontend/dockerfile/dockerfile2llb"
 	"github.com/moby/buildkit/frontend/dockerfile/instructions"
 	"github.com/moby/buildkit/frontend/dockerfile/parser"
 	"github.com/moby/buildkit/frontend/dockerfile/shell"
@@ -66,19 +69,17 @@ var (
 )
 
 func readCopyCmdsFromDockerfile(onlyLastImage bool, absDockerfilePath, workspace string, buildArgs map[string]*string, cfg Config) ([]fromTo, error) {
-	f, err := os.Open(absDockerfilePath)
+	r, err := ioutil.ReadFile(absDockerfilePath)
 	if err != nil {
 		return nil, err
 	}
-	defer f.Close()
 
-	res, err := parser.Parse(f)
+	res, err := parser.Parse(bytes.NewReader(r))
 	if err != nil {
 		return nil, fmt.Errorf("parsing dockerfile %q: %w", absDockerfilePath, err)
 	}
 
-	// instructions.Parse will check for malformed Dockerfile
-	if _, _, err := instructions.Parse(res.AST); err != nil {
+	if err := validateParsedDockerfile(bytes.NewReader(r), res); err != nil {
 		return nil, fmt.Errorf("parsing dockerfile %q: %w", absDockerfilePath, err)
 	}
 
@@ -213,15 +214,16 @@ func extractCopyCommands(nodes []*parser.Node, onlyLastImage bool, cfg Config) (
 		switch node.Value {
 		case command.From:
 			from := fromInstruction(node)
+			if from.as != "" {
+				// Stage names are case insensitive
+				stages[strings.ToLower(from.as)] = true
+			}
+
 			if from.image == "" {
 				// some build args like artifact dependencies are not available until the first build sequence has completed.
 				// skip check if there are unavailable images
 				continue
 			}
-			if from.as != "" {
-				// Stage names are case insensitive
-				stages[strings.ToLower(from.as)] = true
-			}
 
 			// If `from` references a previous stage, then the `workdir`
 			// was already changed.
@@ -323,15 +325,13 @@ func expandOnbuildInstructions(nodes []*parser.Node, cfg Config) ([]*parser.Node
 			expandedNodes = append(expandedNodes, nodes[n:m+1]...)
 			n = m + 1
 
-			if from.image == "" {
-				// some build args like artifact dependencies are not available until the first build sequence has completed.
-				// skip check if there are unavailable images
-				continue
-			}
-
 			var onbuildNodes []*parser.Node
 			if ons, found := onbuildNodesCache[strings.ToLower(from.image)]; found {
 				onbuildNodes = ons
+			} else if from.image == "" {
+				// some build args like artifact dependencies are not available until the first build sequence has completed.
+				// skip check if there are unavailable images
+				onbuildNodes = []*parser.Node{}
 			} else if ons, err := parseOnbuild(from.image, cfg); err == nil {
 				onbuildNodes = ons
 			} else if warnMsg, ok := sErrors.IsOldImageManifestProblem(err); ok && warnMsg != "" {
@@ -425,3 +425,13 @@ func resolveDir(cwd, targetDir string) string {
 	}
 	return path.Clean(path.Join(cwd, targetDir))
 }
+
+func validateParsedDockerfile(r io.Reader, res *parser.Result) error {
+	// skip validation for dockerfiles using explicit `syntax` directive
+	if _, _, _, usesSyntax := dockerfile2llb.DetectSyntax(r); usesSyntax {
+		return nil
+	}
+	// instructions.Parse will check for malformed Dockerfile
+	_, _, err := instructions.Parse(res.AST)
+	return err
+}
