@@ -20,11 +20,8 @@ import (
 	"fmt"
 	"regexp"
 
-	"github.com/sirupsen/logrus"
-
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
-	kubectx "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/context"
-	"github.com/GoogleContainerTools/skaffold/proto"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
+	"github.com/GoogleContainerTools/skaffold/proto/v1"
 )
 
 const (
@@ -42,7 +39,7 @@ type problem struct {
 	regexp      *regexp.Regexp
 	description func(error) string
 	errCode     proto.StatusCode
-	suggestion  func(opts config.SkaffoldOptions) []*proto.Suggestion
+	suggestion  func(runCtx runcontext.RunContext) []*proto.Suggestion
 }
 
 var (
@@ -66,7 +63,7 @@ var (
 			description: func(error) string {
 				return "Build Cancelled."
 			},
-			suggestion: func(config.SkaffoldOptions) []*proto.Suggestion {
+			suggestion: func(_ runcontext.RunContext) []*proto.Suggestion {
 				return nil
 			},
 		},
@@ -76,7 +73,7 @@ var (
 				return "Build Failed"
 			},
 			errCode: proto.StatusCode_BUILD_PROJECT_NOT_FOUND,
-			suggestion: func(config.SkaffoldOptions) []*proto.Suggestion {
+			suggestion: func(_ runcontext.RunContext) []*proto.Suggestion {
 				return []*proto.Suggestion{{
 					SuggestionCode: proto.SuggestionCode_CHECK_GCLOUD_PROJECT,
 					Action:         "Check your GCR project",
@@ -93,7 +90,7 @@ var (
 				}
 				return "Build Failed. Could not connect to Docker daemon"
 			},
-			suggestion: func(config.SkaffoldOptions) []*proto.Suggestion {
+			suggestion: func(runcontext.RunContext) []*proto.Suggestion {
 				return []*proto.Suggestion{{
 					SuggestionCode: proto.SuggestionCode_CHECK_DOCKER_RUNNING,
 					Action:         "Check if docker is running",
@@ -115,8 +112,8 @@ var (
 			return fmt.Sprintf("%s. Ignoring files dependencies for all ONBUILD triggers", pre)
 		},
 		errCode: proto.StatusCode_DEVINIT_UNSUPPORTED_V1_MANIFEST,
-		suggestion: func(opts config.SkaffoldOptions) []*proto.Suggestion {
-			if opts.Command == dev || opts.Command == debug {
+		suggestion: func(runCtx runcontext.RunContext) []*proto.Suggestion {
+			if runCtx.Opts.Command == dev || runCtx.Opts.Command == debug {
 				return []*proto.Suggestion{{
 					SuggestionCode: proto.SuggestionCode_RUN_DOCKER_PULL,
 					Action:         "To avoid, hit Cntrl-C and run `docker pull` to fetch the specified image and retry",
@@ -133,15 +130,10 @@ var (
 			errCode: proto.StatusCode_DEPLOY_CLUSTER_CONNECTION_ERR,
 			description: func(err error) string {
 				matchExp := re("(?i).*unable to connect.*Get (.*)")
-				kubeconfig, parsederr := kubectx.CurrentConfig()
-				if parsederr != nil {
-					logrus.Debugf("Error retrieving the config: %q", parsederr)
-					return fmt.Sprintf("Deploy failed. Could not connect to the cluster due to %s", err)
-				}
 				if match := matchExp.FindStringSubmatch(fmt.Sprintf("%s", err)); len(match) >= 2 {
-					return fmt.Sprintf("Deploy Failed. Could not connect to cluster %s due to %s", kubeconfig.CurrentContext, match[1])
+					return fmt.Sprintf("Deploy Failed. Could not connect to cluster %s due to %s", runCtx.KubeContext, match[1])
 				}
-				return fmt.Sprintf("Deploy Failed. Could not connect to %s cluster.", kubeconfig.CurrentContext)
+				return fmt.Sprintf("Deploy Failed. Could not connect to %s cluster.", runCtx.KubeContext)
 			},
 			suggestion: suggestDeployFailedAction,
 		},
