@@ -25,6 +25,6 @@ func TestForwarderManagerZeroValue(t *testing.T) {
 	var m *ForwarderManager
 
 	// Should not raise a nil dereference
-	m.Start(context.Background())
+	m.Start(context.Background(), nil)
 	m.Stop()
 }
