@@ -37,6 +37,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubectl"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/client"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	schemautil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
@@ -68,7 +69,7 @@ func TestUnavailablePort(t *testing.T) {
 		}
 		pfe := newPortForwardEntry(0, latest.PortForwardResource{}, "", "", "", "", 8080, false)
 
-		k.Forward(context.Background(), pfe)
+		go k.Forward(context.Background(), pfe)
 
 		// wait for isPortFree to be called
 		portFreeWG.Wait()
@@ -108,6 +109,7 @@ func TestMonitorErrorLogs(t *testing.T) {
 		description string
 		input       string
 		cmdRunning  bool
+		shouldError bool
 	}{
 		{
 			description: "no error logs appear",
@@ -117,14 +119,22 @@ func TestMonitorErrorLogs(t *testing.T) {
 		{
 			description: "match on 'error forwarding port'",
 			input:       "error forwarding port 8080",
+			shouldError: true,
 		},
 		{
 			description: "match on 'unable to forward'",
 			input:       "unable to forward 8080",
+			shouldError: true,
 		},
 		{
 			description: "match on 'error upgrading connection'",
 			input:       "error upgrading connection 8080",
+			shouldError: true,
+		},
+		{
+			description: "match on successful port forwarding message",
+			input:       "Forwarding from 127.0.0.1:8080 -> 8080",
+			cmdRunning:  true,
 		},
 	}
 
@@ -143,19 +153,18 @@ func TestMonitorErrorLogs(t *testing.T) {
 				t.Fatalf("error starting command: %v", err)
 			}
 
-			var wg sync.WaitGroup
-			wg.Add(1)
-
+			errChan := make(chan error, 1)
 			go func() {
 				logs := strings.NewReader(test.input)
 
 				k := KubectlForwarder{}
-				k.monitorErrorLogs(ctx, logs, cmd, &portForwardEntry{})
+				k.monitorLogs(ctx, logs, cmd, &portForwardEntry{}, errChan)
 
-				wg.Done()
+				errChan <- nil
 			}()
 
-			wg.Wait()
+			err := <-errChan
+			t.CheckError(test.shouldError, err)
 
 			// make sure the command is running or killed based on what's expected
 			if test.cmdRunning {
@@ -191,29 +200,29 @@ func TestPortForwardArgs(t *testing.T) {
 	}{
 		{
 			description: "non-default address",
-			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "pod", Name: "p", Namespace: "ns", Port: 9, Address: "0.0.0.0"}, "", "", "", "", 8080, false),
+			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "pod", Name: "p", Namespace: "ns", Port: schemautil.FromInt(9), Address: "0.0.0.0"}, "", "", "", "", 8080, false),
 			result:      []string{"--pod-running-timeout", "1s", "--namespace", "ns", "pod/p", "8080:9", "--address", "0.0.0.0"},
 		},
 		{
 			description: "localhost is the default",
-			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "pod", Name: "p", Namespace: "ns", Port: 9, Address: "127.0.0.1"}, "", "", "", "", 8080, false),
+			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "pod", Name: "p", Namespace: "ns", Port: schemautil.FromInt(9), Address: "127.0.0.1"}, "", "", "", "", 8080, false),
 			result:      []string{"--pod-running-timeout", "1s", "--namespace", "ns", "pod/p", "8080:9"},
 		},
 		{
 			description: "no address",
-			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "pod", Name: "p", Namespace: "ns", Port: 9}, "", "", "", "", 8080, false),
+			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "pod", Name: "p", Namespace: "ns", Port: schemautil.FromInt(9)}, "", "", "", "", 8080, false),
 			result:      []string{"--pod-running-timeout", "1s", "--namespace", "ns", "pod/p", "8080:9"},
 		},
 		{
 			description: "service to pod",
-			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "service", Name: "svc", Namespace: "ns", Port: 9}, "", "", "", "", 8080, false),
+			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "service", Name: "svc", Namespace: "ns", Port: schemautil.FromInt(9)}, "", "", "", "", 8080, false),
 			servicePod:  "servicePod",
 			servicePort: 9999,
 			result:      []string{"--pod-running-timeout", "1s", "--namespace", "ns", "pod/servicePod", "8080:9999"},
 		},
 		{
 			description: "service could not be mapped to pod",
-			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "service", Name: "svc", Namespace: "ns", Port: 9}, "", "", "", "", 8080, false),
+			input:       newPortForwardEntry(0, latest.PortForwardResource{Type: "service", Name: "svc", Namespace: "ns", Port: schemautil.FromInt(9)}, "", "", "", "", 8080, false),
 			serviceErr:  errors.New("error"),
 			result:      []string{"--pod-running-timeout", "1s", "--namespace", "ns", "service/svc", "8080:9"},
 		},
@@ -224,7 +233,7 @@ func TestPortForwardArgs(t *testing.T) {
 			ctx, cancel := context.WithTimeout(context.Background(), 100*time.Millisecond)
 			defer cancel()
 
-			t.Override(&findNewestPodForSvc, func(ctx context.Context, ns, serviceName string, servicePort int) (string, int, error) {
+			t.Override(&findNewestPodForSvc, func(ctx context.Context, ns, serviceName string, servicePort schemautil.IntOrString) (string, int, error) {
 				return test.servicePod, test.servicePort, test.serviceErr
 			})
 
@@ -251,28 +260,34 @@ func TestFindServicePort(t *testing.T) {
 	tests := []struct {
 		description string
 		service     *corev1.Service
-		port        int
+		port        schemautil.IntOrString
 		shouldErr   bool
 		expected    corev1.ServicePort
 	}{
 		{
 			description: "simple case",
 			service:     mockService("svc1", corev1.ServiceTypeLoadBalancer, []corev1.ServicePort{{Port: 90, TargetPort: intstr.FromInt(80)}, {Port: 80, TargetPort: intstr.FromInt(8080)}}),
-			port:        80,
+			port:        schemautil.FromInt(80),
 			expected:    corev1.ServicePort{Port: 80, TargetPort: intstr.FromInt(8080)},
 		},
 		{
 			description: "no ports",
 			service:     mockService("svc2", corev1.ServiceTypeLoadBalancer, nil),
-			port:        80,
+			port:        schemautil.FromInt(80),
 			shouldErr:   true,
 		},
 		{
 			description: "no matching ports",
 			service:     mockService("svc3", corev1.ServiceTypeLoadBalancer, []corev1.ServicePort{{Port: 90, TargetPort: intstr.FromInt(80)}, {Port: 80, TargetPort: intstr.FromInt(8080)}}),
-			port:        100,
+			port:        schemautil.FromInt(100),
 			shouldErr:   true,
 		},
+		{
+			description: "simple case with service port names",
+			service:     mockService("svc1", corev1.ServiceTypeLoadBalancer, []corev1.ServicePort{{Name: "aaa", Port: 90, TargetPort: intstr.FromInt(80)}, {Name: "bbb", Port: 80, TargetPort: intstr.FromInt(8080)}}),
+			port:        schemautil.FromString("bbb"),
+			expected:    corev1.ServicePort{Name: "bbb", Port: 80, TargetPort: intstr.FromInt(8080)},
+		},
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
@@ -403,7 +418,7 @@ func TestFindNewestPodForService(t *testing.T) {
 				return fake.NewSimpleClientset(test.clientResources...), test.clientErr
 			})
 
-			pod, port, err := findNewestPodForService(ctx, "", test.serviceName, test.servicePort)
+			pod, port, err := findNewestPodForService(ctx, "", test.serviceName, schemautil.FromInt(test.servicePort))
 			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.chosenPod, pod)
 			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.chosenPort, port)
 		})
