@@ -19,7 +19,6 @@ package runcontext
 import (
 	"fmt"
 	"os"
-	"sort"
 
 	"github.com/sirupsen/logrus"
 
@@ -27,6 +26,7 @@ import (
 	kubectx "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/context"
 	runnerutil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
 const (
@@ -81,6 +81,14 @@ func (ps Pipelines) Artifacts() []*latest.Artifact {
 	return artifacts
 }
 
+func (ps Pipelines) DeployConfigs() []latest.DeployConfig {
+	var cfgs []latest.DeployConfig
+	for _, p := range ps.pipelines {
+		cfgs = append(cfgs, p.Deploy)
+	}
+	return cfgs
+}
+
 func (ps Pipelines) Deployers() []latest.DeployType {
 	var deployers []latest.DeployType
 	for _, p := range ps.pipelines {
@@ -127,6 +135,8 @@ func (rc *RunContext) PortForwardResources() []*latest.PortForwardResource {
 
 func (rc *RunContext) Artifacts() []*latest.Artifact { return rc.Pipelines.Artifacts() }
 
+func (rc *RunContext) DeployConfigs() []latest.DeployConfig { return rc.Pipelines.DeployConfigs() }
+
 func (rc *RunContext) Deployers() []latest.DeployType { return rc.Pipelines.Deployers() }
 
 func (rc *RunContext) TestCases() []*latest.TestCase { return rc.Pipelines.TestCases() }
@@ -159,6 +169,7 @@ func (rc *RunContext) ForceDeploy() bool                         { return rc.Opt
 func (rc *RunContext) GetKubeConfig() string                     { return rc.Opts.KubeConfig }
 func (rc *RunContext) GetKubeNamespace() string                  { return rc.Opts.Namespace }
 func (rc *RunContext) GlobalConfig() string                      { return rc.Opts.GlobalConfig }
+func (rc *RunContext) HydratedManifests() []string               { return rc.Opts.HydratedManifests }
 func (rc *RunContext) MinikubeProfile() string                   { return rc.Opts.MinikubeProfile }
 func (rc *RunContext) Muted() config.Muted                       { return rc.Opts.Muted }
 func (rc *RunContext) NoPruneChildren() bool                     { return rc.Opts.NoPruneChildren }
@@ -234,20 +245,8 @@ func (rc *RunContext) UpdateNamespaces(ns []string) {
 	if len(ns) == 0 {
 		return
 	}
-
-	nsMap := map[string]bool{}
-	for _, ns := range append(ns, rc.Namespaces...) {
-		if ns == emptyNamespace {
-			continue
-		}
-		nsMap[ns] = true
-	}
-
-	// Update RunContext Namespace
-	updated := make([]string, 0, len(nsMap))
-	for k := range nsMap {
-		updated = append(updated, k)
-	}
-	sort.Strings(updated)
-	rc.Namespaces = updated
+	namespaces := util.NewStringSet()
+	namespaces.Insert(append(rc.Namespaces, ns...)...)
+	namespaces.Delete(emptyNamespace)
+	rc.Namespaces = namespaces.ToList()
 }
