@@ -34,7 +34,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/yamltags"
-	"github.com/GoogleContainerTools/skaffold/proto"
+	"github.com/GoogleContainerTools/skaffold/proto/v1"
 )
 
 var (
@@ -45,10 +45,9 @@ var (
 
 // Process checks if the Skaffold pipeline is valid and returns all encountered errors as a concatenated string
 func Process(configs []*latest.SkaffoldConfig) error {
-	var errs []error
+	var errs = validateImageNames(configs)
 	for _, config := range configs {
-		errs = visitStructs(config, validateYamltags)
-		errs = append(errs, validateImageNames(config.Build.Artifacts)...)
+		errs = append(errs, visitStructs(config, validateYamltags)...)
 		errs = append(errs, validateDockerNetworkMode(config.Build.Artifacts)...)
 		errs = append(errs, validateCustomDependencies(config.Build.Artifacts)...)
 		errs = append(errs, validateSyncRules(config.Build.Artifacts)...)
@@ -57,6 +56,7 @@ func Process(configs []*latest.SkaffoldConfig) error {
 		errs = append(errs, validateLogPrefix(config.Deploy.Logs)...)
 		errs = append(errs, validateArtifactTypes(config.Build)...)
 		errs = append(errs, validateTaggingPolicy(config.Build)...)
+		errs = append(errs, validateCustomTest(config.Test)...)
 	}
 	errs = append(errs, validateArtifactDependencies(configs)...)
 	errs = append(errs, validateSingleKubeContext(configs)...)
@@ -98,22 +98,31 @@ func validateTaggingPolicy(bc latest.BuildConfig) (errs []error) {
 	return
 }
 
-// validateImageNames makes sure the artifact image names are valid base names,
+// validateImageNames makes sure the artifact image names are unique and valid base names,
 // without tags nor digests.
-func validateImageNames(artifacts []*latest.Artifact) (errs []error) {
-	for _, a := range artifacts {
-		parsed, err := docker.ParseReference(a.ImageName)
-		if err != nil {
-			errs = append(errs, fmt.Errorf("invalid imageName '%s': %v", a.ImageName, err))
-			continue
-		}
+func validateImageNames(configs []*latest.SkaffoldConfig) (errs []error) {
+	seen := make(map[string]bool)
+	for _, c := range configs {
+		for _, a := range c.Build.Artifacts {
+			if seen[a.ImageName] {
+				errs = append(errs, fmt.Errorf("found duplicate images %q: artifact image names must be unique across all configurations", a.ImageName))
+				continue
+			}
 
-		if parsed.Tag != "" {
-			errs = append(errs, fmt.Errorf("invalid imageName '%s': no tag should be specified. Use taggers instead: https://skaffold.dev/docs/how-tos/taggers/", a.ImageName))
-		}
+			seen[a.ImageName] = true
+			parsed, err := docker.ParseReference(a.ImageName)
+			if err != nil {
+				errs = append(errs, fmt.Errorf("invalid image %q: %w", a.ImageName, err))
+				continue
+			}
 
-		if parsed.Digest != "" {
-			errs = append(errs, fmt.Errorf("invalid imageName '%s': no digest should be specified. Use taggers instead: https://skaffold.dev/docs/how-tos/taggers/", a.ImageName))
+			if parsed.Tag != "" {
+				errs = append(errs, fmt.Errorf("invalid image %q: no tag should be specified. Use taggers instead: https://skaffold.dev/docs/how-tos/taggers/", a.ImageName))
+			}
+
+			if parsed.Digest != "" {
+				errs = append(errs, fmt.Errorf("invalid image %q: no digest should be specified. Use taggers instead: https://skaffold.dev/docs/how-tos/taggers/", a.ImageName))
+			}
 		}
 	}
 	return
@@ -471,3 +480,28 @@ func validateSingleKubeContext(configs []*latest.SkaffoldConfig) []error {
 	}
 	return nil
 }
+
+// validateCustomTest
+// - makes sure that command is not empty
+// - makes sure that dependencies.ignore is only used in conjunction with dependencies.paths
+func validateCustomTest(tcs []*latest.TestCase) (errs []error) {
+	for _, tc := range tcs {
+		for _, ct := range tc.CustomTests {
+			if ct.Command == "" {
+				errs = append(errs, fmt.Errorf("custom test command must not be empty;"))
+				return
+			}
+
+			if ct.Dependencies == nil {
+				continue
+			}
+			if ct.Dependencies.Command != "" && ct.Dependencies.Paths != nil {
+				errs = append(errs, fmt.Errorf("dependencies can use either command or paths, but not both"))
+			}
+			if ct.Dependencies.Paths == nil && ct.Dependencies.Ignore != nil {
+				errs = append(errs, fmt.Errorf("customTest has invalid dependencies; dependencies.ignore can only be used in conjunction with dependencies.paths"))
+			}
+		}
+	}
+	return
+}
