@@ -20,7 +20,7 @@ import (
 	"fmt"
 
 	sErrors "github.com/GoogleContainerTools/skaffold/pkg/skaffold/errors"
-	"github.com/GoogleContainerTools/skaffold/proto"
+	"github.com/GoogleContainerTools/skaffold/proto/v1"
 )
 
 func containerStructureTestErr(err error) error {
@@ -31,3 +31,21 @@ func containerStructureTestErr(err error) error {
 		},
 	)
 }
+
+func expandingFilePathsErr(err error) error {
+	return sErrors.NewError(err,
+		proto.ActionableErr{
+			Message: fmt.Sprintf("expanding test file paths: %s", err),
+			ErrCode: proto.StatusCode_TEST_USER_CONFIG_ERR,
+		},
+	)
+}
+
+func dockerPullImageErr(fqn string, err error) (string, error) {
+	return "", sErrors.NewError(err,
+		proto.ActionableErr{
+			Message: fmt.Sprintf("unable to docker pull image %s: %s", fqn, err),
+			ErrCode: proto.StatusCode_TEST_IMG_PULL_ERR,
+		},
+	)
+}
